Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToLatin ¶
ToLatin attempts to convert provided source string into latin characters using conversion dictionary, based on russian keyboard layout.
For example "Ащщ" will be converted into "Foo"
Conversion will be applied only if all characters inside string can be converted, so this function does not work in partial mode.
If coversion is successful, this function will return result and true. In other cases this func will return source string and false.
PS. Works on standard Windows keyboard layouts.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.